
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef aspect_MSG_LIB_H
#define aspect_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "aspectType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  ASPECT_MBOX_NAME                  genomInstanceName("aspect")

#define  ASPECT_MAX_RQST_SIZE              80

#define  ASPECT_MBOX_RQST_SIZE       \
 (BUF_SIZE(ASPECT_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  ASPECT_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  ASPECT_MAX_REPLY_SIZE             72

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  ASPECT_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(ASPECT_MAX_REPLY_SIZE) \
   + BUF_SIZE(ASPECT_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define ASPECT_SETVIEWPARAMETERS_RQST 0
#define ASPECT_GETVIEWPARAMETERS_RQST 1
#define ASPECT_READMAP_RQST 2
#define ASPECT_GETMAPSOURCE_RQST 3
#define ASPECT_SETDYNAMICSEGSSOURCE_RQST 4
#define ASPECT_GETDYNAMICSEGSSOURCE_RQST 5
#define ASPECT_RESETMAP_RQST 6
#define ASPECT_ASPECTFROMPOSTERCONFIG_RQST 7
#define ASPECT_STOPASPECT_RQST 8
#define ASPECT_EXPORTLASER_RQST 9
#define ASPECT_GETLASERPARAMS_RQST 10
#define ASPECT_ABORT_RQST 11


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS aspectClientInit (CLIENT_ID *pClientId);

STATUS aspectClientEnd (CLIENT_ID clientId);

int aspectAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int aspectAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int aspectAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS aspectSetViewParametersRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ASPECT_VIEW_PARAMETERS *(in_viewParameters),
					 int replyTimeOut);

int aspectSetViewParametersReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int aspectSetViewParametersRqstAndRcv (CLIENT_ID clientId, 
				 ASPECT_VIEW_PARAMETERS *(in_viewParameters), 
				 
				 int *bilan);




extern STATUS aspectGetViewParametersRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int aspectGetViewParametersReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       ASPECT_VIEW_PARAMETERS *(out_viewParameters),
			       int *bilan);

int aspectGetViewParametersRqstAndRcv (CLIENT_ID clientId, 
				  
				 ASPECT_VIEW_PARAMETERS *(out_viewParameters),
				 int *bilan);




extern STATUS aspectReadMapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ASPECT_INPUT_SOURCE *(in_mapInput),
					 int replyTimeOut);

extern int aspectReadMapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      int *(out_nbReadMapSegs),
				      int *activity, int *bilan);


extern int aspectReadMapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ASPECT_INPUT_SOURCE *(in_mapInput), 
					int *(out_nbReadMapSegs),
					int *activity, int *bilan);

extern int aspectReadMapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ASPECT_INPUT_SOURCE *(in_mapInput), 
					int *(out_nbReadMapSegs),
					int *activity,
					int *bilan);




extern STATUS aspectGetMapSourceRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int aspectGetMapSourceReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       ASPECT_INPUT_SOURCE *(out_mapInput),
			       int *bilan);

int aspectGetMapSourceRqstAndRcv (CLIENT_ID clientId, 
				  
				 ASPECT_INPUT_SOURCE *(out_mapInput),
				 int *bilan);




extern STATUS aspectSetDynamicSegsSourceRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ASPECT_STRING *(in_segsPosterName),
					 int replyTimeOut);

extern int aspectSetDynamicSegsSourceReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int aspectSetDynamicSegsSourceRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ASPECT_STRING *(in_segsPosterName), 
					
					int *activity, int *bilan);

extern int aspectSetDynamicSegsSourceRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ASPECT_STRING *(in_segsPosterName), 
					
					int *activity,
					int *bilan);




extern STATUS aspectGetDynamicSegsSourceRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int aspectGetDynamicSegsSourceReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       ASPECT_STRING *(out_segsPosterName),
			       int *bilan);

int aspectGetDynamicSegsSourceRqstAndRcv (CLIENT_ID clientId, 
				  
				 ASPECT_STRING *(out_segsPosterName),
				 int *bilan);




extern STATUS aspectResetMapRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int aspectResetMapReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int aspectResetMapRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int aspectResetMapRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS aspectAspectFromPosterConfigRqstSend (CLIENT_ID clientId, int *pRqstId,
					 ASPECT_INPUTS_POSTER *(in_inputsPoster),
					 int replyTimeOut);

extern int aspectAspectFromPosterConfigReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int aspectAspectFromPosterConfigRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					ASPECT_INPUTS_POSTER *(in_inputsPoster), 
					
					int *activity, int *bilan);

extern int aspectAspectFromPosterConfigRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					ASPECT_INPUTS_POSTER *(in_inputsPoster), 
					
					int *activity,
					int *bilan);




extern STATUS aspectStopAspectRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int aspectStopAspectReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int aspectStopAspectRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS aspectExportLaserRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 ASPECT_EXPORT_LASER *(in_exportLaser),
					 int replyTimeOut);

int aspectExportLaserReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int aspectExportLaserRqstAndRcv (CLIENT_ID clientId, 
				 ASPECT_EXPORT_LASER *(in_exportLaser), 
				 
				 int *bilan);




extern STATUS aspectGetLaserParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int aspectGetLaserParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       ASPECT_EXPORT_LASER *(out_exportLaser),
			       int *bilan);

int aspectGetLaserParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 ASPECT_EXPORT_LASER *(out_exportLaser),
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* aspect_MSG_LIB_H */

